@@ -33,7 +33,7 @@ public:
     HazeAccountUiPlugin(QObject *parent, const QVariantList &);
     virtual ~HazeAccountUiPlugin();
 
-    virtual AbstractAccountUi* accountUi(const QString &connectionManager, const QString &protocol, const QString &serviceName);
+    virtual AbstractAccountUi* accountUi(const QString &connectionManager, const QString &protocol, const QString &serviceName) override;
 
 private:
     Q_DISABLE_COPY(HazeAccountUiPlugin)
